from typing import Any

def in_transaction(): ...
def transaction(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transaction_async(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transaction_async_(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transactional(retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...): ...
def transactional_async(retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...): ...
def transactional_tasklet(
    retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def non_transactional(allow_existing: bool = ...): ...
